@@ -77,13 +77,18 @@ class OVSController:
         """
         for ovs_sw in emulation_env_config.ovs_config.switch_configs:
             if ovs_sw.physical_host_ip != physical_server_ip:
+                logger.info(f"Wrong host IP of switch: {ovs_sw.container_name}, {ovs_sw.physical_host_ip}, "
+                            f"{physical_server_ip}")
                 continue
-            logger.info(f"Configuring OVS bridge on container: {ovs_sw.container_name}")
+            logger.info(f"Configuring OVS bridge on container: {ovs_sw.container_name}, "
+                        f"physical host: {ovs_sw.physical_host_ip}, gw ip: {ovs_sw.docker_gw_bridge_ip}")
             EmulationUtil.connect_admin(emulation_env_config=emulation_env_config, ip=ovs_sw.docker_gw_bridge_ip)
             bridge_name = constants.OVS.DEFAULT_BRIDGE_NAME
             cmd = f"{constants.COMMANDS.SUDO} {constants.OVS.OVS_VSCTL} set bridge {bridge_name} " \
                   f"protocols={','.join(ovs_sw.openflow_protocols)}"
+            logger.info(f"Running cmd:{cmd} on container: {ovs_sw.container_name}")
             EmulationUtil.execute_ssh_cmd(cmd=cmd, conn=emulation_env_config.connections[ovs_sw.docker_gw_bridge_ip])
             cmd = f"{constants.COMMANDS.SUDO} {constants.OVS.OVS_VSCTL} set-controller {bridge_name} " \
                   f"{ovs_sw.controller_transport_protocol}:{ovs_sw.controller_ip}:{ovs_sw.controller_port}"
+            logger.info(f"Running cmd:{cmd} on container: {ovs_sw.container_name}")
             EmulationUtil.execute_ssh_cmd(cmd=cmd, conn=emulation_env_config.connections[ovs_sw.docker_gw_bridge_ip])
